@@ -100,7 +100,9 @@ GtkDuecaView::GtkDuecaView(Entity *e, const char *part,
   cb(this, &GtkDuecaView::updateInterface),
   update_interface(getId(), "update dueca interface", &cb,
                    PrioritySpec(0, -20)),
-  waker()
+  waker(),
+  previous_command_state(),
+  previous_confirmed_state()
 {
   // update the singleton pointer. Note that checking is done in the
   // base class.
@@ -296,7 +298,6 @@ bool GtkDuecaView::complete()
     gtk_window_set_transient_for(GTK_WINDOW(gw_common["dont_change_a_running"]),
                                  GTK_WINDOW(window["dueca_if"]));
 
-
     if (!gw_common["select_md2"]) {
       /* DUECA UI.
 
@@ -308,9 +309,6 @@ bool GtkDuecaView::complete()
     }
     gtk_window_set_transient_for(GTK_WINDOW(gw_common["select_md2"]),
                                  GTK_WINDOW(window["dueca_if"]));
-
-
-
   }
 
   return res;
@@ -654,48 +652,88 @@ void GtkDuecaView::updateEntityButtons(const ModuleState &confirmed_state,
                                        bool emergency_flag)
 {
   if (!simple_io) {
-    switch (confirmed_state.get()) {
-    case ModuleState::InitialPrep:
-      if (command_state == confirmed_state) {
-        gtk_dueca_button_set_image(hw_off, 2);
+
+    if (command_state != previous_command_state) {
+
+      // set the button images for the previously active buttons
+      switch (previous_command_state.get()) {
+      case ModuleState::On:
+        gtk_dueca_button_set_image(hw_on, 0);
+        break;
+      case ModuleState::Prepared:
+      case ModuleState::Safe:
+        gtk_dueca_button_set_image(hw_safe, 0);
+        break;
+      case ModuleState::InitialPrep:
+        gtk_dueca_button_set_image(hw_off, 0);
+      default:
+        break;
       }
-      gtk_widget_set_sensitive(hw_off, TRUE);
-      gtk_widget_set_sensitive(hw_safe, TRUE);
-      gtk_widget_set_sensitive(hw_on, FALSE);
-      break;
-    case ModuleState::Safe:
-      gtk_dueca_button_set_image(hw_safe, 2);
-      gtk_widget_set_sensitive(hw_off, TRUE);
-      if (!emergency_flag) {
-        gtk_widget_set_sensitive(hw_safe, TRUE);
+      previous_command_state = command_state;
+
+      // set the button images for the commanded state to transient
+      if (command_state != confirmed_state) {
+        switch (command_state.get()) {
+        case ModuleState::On:
+          gtk_dueca_button_set_image(hw_on, 1);
+          break;
+        case ModuleState::Prepared:
+        case ModuleState::Safe:
+          gtk_dueca_button_set_image(hw_safe, 1);
+          break;
+        case ModuleState::InitialPrep:
+          gtk_dueca_button_set_image(hw_off, 1);
+        default:
+          break;
+        }
       }
-      gtk_widget_set_sensitive(hw_on, FALSE);
-      break;
-    case ModuleState::Prepared:
-      gtk_dueca_button_set_image(hw_safe, 2);
-      gtk_widget_set_sensitive(hw_off, TRUE);
-      if (!emergency_flag) {
+    }
+
+    if (confirmed_state != previous_confirmed_state) {
+      switch (confirmed_state.get()) {
+      case ModuleState::InitialPrep:
+        if (command_state == confirmed_state) {
+          gtk_dueca_button_set_image(hw_off, 2);
+        }
+        gtk_widget_set_sensitive(hw_off, TRUE);
         gtk_widget_set_sensitive(hw_safe, TRUE);
+        gtk_widget_set_sensitive(hw_on, FALSE);
+        break;
+      case ModuleState::Safe:
+        gtk_dueca_button_set_image(hw_safe, 2);
+        gtk_widget_set_sensitive(hw_off, TRUE);
+        if (!emergency_flag) {
+          gtk_widget_set_sensitive(hw_safe, TRUE);
+        }
+        gtk_widget_set_sensitive(hw_on, FALSE);
+        break;
+      case ModuleState::Prepared:
+        gtk_dueca_button_set_image(hw_safe, 2);
+        gtk_widget_set_sensitive(hw_off, TRUE);
+        if (!emergency_flag) {
+          gtk_widget_set_sensitive(hw_safe, TRUE);
+          gtk_widget_set_sensitive(hw_on, TRUE);
+        }
+        break;
+      case ModuleState::On:
+        if (command_state == confirmed_state) {
+          gtk_dueca_button_set_image(hw_on, 2);
+        }
+        gtk_widget_set_sensitive(hw_off, FALSE);
+        if (please_keep_running) {
+          gtk_widget_set_sensitive(hw_safe, FALSE);
+        }
+        else {
+          gtk_widget_set_sensitive(hw_safe, TRUE);
+        }
         gtk_widget_set_sensitive(hw_on, TRUE);
-      }
-      break;
-    case ModuleState::On:
-      if (command_state == confirmed_state) {
-        gtk_dueca_button_set_image(hw_on, 2);
-      }
-      gtk_widget_set_sensitive(hw_off, FALSE);
-      if (please_keep_running) {
-        gtk_widget_set_sensitive(hw_safe, FALSE);
-      }
-      else {
-        gtk_widget_set_sensitive(hw_safe, TRUE);
-      }
-      gtk_widget_set_sensitive(hw_on, TRUE);
-      break;
-    default:
+        break;
+      default:
 
       // Unprepared Neutral and Undefined
-      break;
+        break;
+      }
+      previous_confirmed_state = confirmed_state;
     }
   }
 }
