@@ -275,7 +275,8 @@ bool GtkGladeWindow::_setValue(const char *wname, const char *value, bool warn)
     GtkTreeIter it;
     gboolean itvalid = gtk_tree_model_get_iter_first(mdl, &it);
     gchararray val = NULL;
-    gtk_tree_model_get(mdl, &it, 0, &val, -1);
+    if (itvalid)
+      gtk_tree_model_get(mdl, &it, 0, &val, -1);
 
     while (itvalid && strcmp(val, value)) {
       itvalid = gtk_tree_model_iter_next(mdl, &it);
@@ -604,8 +605,19 @@ bool GtkGladeWindow::_getValue(const char *wname, const CommObjectWriter &cor,
   return false;
 }
 
-unsigned GtkGladeWindow::setValues(CommObjectReader &dco, const char *format,
-                                   const char *arrformat, bool warn)
+template <>
+unsigned GtkGladeWindow::setValues<DCOReader>(DCOReader &dco,
+                                              const char *format,
+                                              const char *arrformat, bool warn)
+{
+  return setValues<CommObjectReader>(dco, format, arrformat, warn);
+}
+
+template <>
+unsigned GtkGladeWindow::setValues<CommObjectReader>(CommObjectReader &dco,
+                                                     const char *format,
+                                                     const char *arrformat,
+                                                     bool warn)
 {
   unsigned nset = 0;
   char gtkid[128];
@@ -737,8 +749,19 @@ bool GtkGladeWindow::_setRadiosFromEnum(const char *gtkid,
   return false;
 }
 
-unsigned GtkGladeWindow::getValues(CommObjectWriter &dco, const char *format,
-                                   const char *arrformat, bool warn)
+template <>
+unsigned GtkGladeWindow::getValues<DCOWriter>(DCOWriter &dco,
+                                              const char *format,
+                                              const char *arrformat, bool warn)
+{
+  return getValues<CommObjectWriter>(dco, format, arrformat, warn);
+}
+
+template <>
+unsigned GtkGladeWindow::getValues<CommObjectWriter>(CommObjectWriter &dco,
+                                                     const char *format,
+                                                     const char *arrformat,
+                                                     bool warn)
 {
   unsigned nset = 0;
   char gtkid[128];
